@@ -156,7 +156,6 @@ void Account::copyAccount( const Account *account )
                                   account->getUseListFormatting()                  );
   setEmailInformation           ( account->getShowEmail(),
                                   account->getShowOtherFolders()                   );
-  setEmoticonStyle              ( account->getEmoticonStyle()                      );
   setFontInformation            ( account->getFont(),
                                   account->getFontColor(),
                                   account->getContactFont(),
@@ -176,6 +175,7 @@ void Account::copyAccount( const Account *account )
   setStatusOptions              ( account->getUseIdleTimer(),
                                   account->getIdleTime(),
                                   account->getHideNotificationsWhenBusy()          );
+  setEmoticonStyle              ( account->getEmoticonStyle()                      );
 
   // With direct copying we can quickly duplicate those properties
   // for which we don't need to send updates
@@ -1220,6 +1220,9 @@ void Account::setEmoticonStyle( const QString& emoticonStyle )
     emoticonStyle_ = emoticonStyle;
     emit changedEmoticonSettings();
 
+    // update friendly name. horrible.
+    friendlyName_.setString( friendlyName_.getOriginal() );
+
     // Tell the account settings changed and need to be saved
     dirty_ = true;
 #ifdef KMESSDEBUG_ACCOUNT_DIRTY
