@@ -928,13 +928,13 @@ void Chat::sendChatMessage( const QString &message )
 
 
 // Send an ink drawing to the current chat
-void Chat::sendInkMessage( const QByteArray &inkData )
+void Chat::sendInkMessage( InkFormat format, const QByteArray &inkData )
 {
 #ifdef KMESSTEST
   KMESS_ASSERT( msnSwitchboardConnection_ );
 #endif
 
-  msnSwitchboardConnection_->sendInk( inkData );
+  msnSwitchboardConnection_->sendInk( format, inkData );
 }
 
 
@@ -1204,6 +1204,16 @@ void Chat::showWarning( MsnSwitchboardConnection::WarningType type, ContactBase
                                 friendlyName ) );
       break;
 
+    case MsnSwitchboardConnection::WARNING_INK_UNSUPPORTED_BY_CONTACT:
+      showMessage( ChatMessage( ChatMessage::TYPE_SYSTEM,
+                                ChatMessage::CONTENT_SYSTEM_ERROR,
+                                true,
+                                i18nc( "Warning message shown in chat",
+                                       "One or more contacts do not support the handwriting message." ),
+                                handle,
+                                friendlyName ) );
+      break;
+
     case MsnSwitchboardConnection::WARNING_UNSUPPORTED_UNKNOWN:
 #ifdef KMESSTEST
       KMESS_ASSERT( contact != 0 );
