@@ -1284,7 +1284,7 @@ void ChatMaster::slotDeliverMimeMessage(const MimeMessage &message, const QStrin
 
 
 // Parse an gif ink message
-void ChatMaster::slotGotInkMessage( const QString &inkData, const QString &contactHandle, InkFormat format )
+void ChatMaster::slotGotInkMessage( const QString &ink, const QString &contactHandle, InkFormat format )
 {
 #ifdef KMESSDEBUG_SWITCHBOARD_GENERAL
   switch( format )
@@ -1315,7 +1315,7 @@ void ChatMaster::slotGotInkMessage( const QString &inkData, const QString &conta
                                      i18nc( "Error message shown in chat, %1 is the name of the contact",
                                             "You received an handwritten message from %1, "
                                             "but it could not be displayed. This version of "
-                                            "KMess was built without ISF support." ),
+                                            "KMess was built without ISF support.", friendlyName ),
                                      contactHandle,
                                      friendlyName ) );
     return;
@@ -1324,6 +1324,7 @@ void ChatMaster::slotGotInkMessage( const QString &inkData, const QString &conta
 
 
   // Validate the incoming data
+  QString inkData = ink.trimmed();
   QRegExp inkChars( "([^A-Za-z0-9:+/=])" );
   if( ! inkData.startsWith( "base64:" ) || inkChars.indexIn( inkData ) != -1 )
   {
@@ -1336,7 +1337,7 @@ void ChatMaster::slotGotInkMessage( const QString &inkData, const QString &conta
                                      i18nc( "Error message shown in chat, %1 is the name of the contact",
                                             "You received an handwritten message from %1, "
                                             "but it could not be displayed. The data could "
-                                            "not be read." ),
+                                            "not be read.", friendlyName ),
                                      contactHandle,
                                      friendlyName ) );
     return;
