@@ -407,7 +407,7 @@ QString ChatMessageView::getHistory( Account::ChatExportFormat format, bool appe
           }
           else
           {
-            chatHistory += "("  + chatMessage->getTime().toString( Qt::DefaultLocaleShortDate ) + ")"
+            chatHistory += "("  + KGlobal::locale()->formatTime( chatMessage->getTime() ) + ")"
                            " "  + chatMessage->getContactHandle() + ":\n"
                            "  " + chatMessage->getBody().trimmed() + "\n";
           }
@@ -416,7 +416,7 @@ QString ChatMessageView::getHistory( Account::ChatExportFormat format, bool appe
         // Add system messages etc
         else
         {
-          chatHistory += "(" + chatMessage->getTime().toString( Qt::DefaultLocaleShortDate ) + ")"
+          chatHistory += "(" + KGlobal::locale()->formatTime( chatMessage->getTime() ) + ")"
                          " " + chatMessage->getBody().trimmed() + "\n";
           lastHandle = QString();
         }
