@@ -469,7 +469,18 @@ bool ChatView::saveChatToFile( const QString &path, Account::ChatExportFormat fo
 
   // Output the chat history to the file, with the right text encoding
   QTextStream textStream( &file );
-  textStream.setCodec( QTextCodec::codecForLocale() );
+  
+  // For plain text logs we use the locale codec
+  if (format == Account::EXPORT_TEXT)
+  {
+    textStream.setCodec( QTextCodec::codecForLocale() );
+  }
+  // For HTML and XML logs (that are created with charset attribute to UTF-8) we use UTF-8 encoding
+  else
+  {
+    textStream.setCodec( QTextCodec::codecForName("UTF-8") );
+  }
+  
   textStream << chatHistory;
   file.close();
 
@@ -658,7 +669,7 @@ void ChatView::slotAddNewEmoticon()
 
   // URL-Decode the encoded strings
   picture  = KUrl::fromPercentEncoding( picture.toAscii()  );
-  shortcut = KUrl::fromPercentEncoding( shortcut.toAscii() );
+  shortcut = KUrl::fromPercentEncoding( shortcut.toUtf8() );
 
 #ifdef KMESSDEBUG_CHATVIEW
   kDebug() << "Showing Add Emoticon dialog - shortcut=" << shortcut << " picture=" << picture;
@@ -773,7 +784,7 @@ void ChatView::slotIgnoreEmoticon()
   }
 
   // URL-Decode the encoded strings
-  shortcut = KUrl::fromPercentEncoding( shortcut.toAscii() );
+  shortcut = KUrl::fromPercentEncoding( shortcut.toUtf8() );
 
   // Add the emoticon to the contact's blacklist and update the chat
   if( contact->manageEmoticonBlackList( true, shortcut ) )
