@@ -44,6 +44,7 @@
 #include <QDockWidget>
 #include <QShortcut>
 #include <QTextDocumentFragment>
+#include <QDesktopWidget>
 
 #include <KAction>
 #include <KActionMenu>
@@ -281,6 +282,11 @@ Chat *ChatWindow::addChatTab( Chat *newChat, bool foreground )
   newChat->getContactsWidget()->setDockWidget( contactsDock_, dockWidgetArea( contactsDock_ ) );
   newChat->setZoomFactor( zoomLevel_ );
 
+  // Enable the spell checker for the new tab.
+  // FIXME KDE4.x bug this needs to be unset then set
+  messageEdit_->setCheckSpellingEnabled( ! spellCheckAction_->isChecked() );
+  messageEdit_->setCheckSpellingEnabled( spellCheckAction_->isChecked() );
+
   // If there's more than one tab now, enable the Close All option
   bool hasMultipleTabs = ( chatTabs_->count() > 1 );
   closeAllAction_->setEnabled( hasMultipleTabs );
@@ -733,7 +739,7 @@ bool ChatWindow::eventFilter( QObject *obj, QEvent *event )
 
     return false;
   }
-  
+
   if ( event->type() == QEvent::KeyPress )
   {
     QKeyEvent *keyEvent = static_cast<QKeyEvent*>( event );
@@ -743,7 +749,7 @@ bool ChatWindow::eventFilter( QObject *obj, QEvent *event )
       return true;
     }
   }
-  
+
   // Only manage events for the editors from now on (the event filter code
   // is complex enough as it is now...)
   if( obj != messageEdit_
@@ -1383,8 +1389,24 @@ void ChatWindow::readProperties(const KConfigGroup &config )
 
   // Resize the window to decent dimensions if there's no saved state.
   resize( 550, 450 );
-  restoreState( group.readEntry( "ToolbarsAndDocksState", QByteArray() ) );
+
+  QByteArray state( group.readEntry( "ToolbarsAndDocksState", QByteArray()  ) );
+
+  // adam (16Feb10): restoreWindowSize has to come before restoreState.
+  //
+  // when testing with KDE 4.4 I found, for some completely unknown reason,
+  // that calling restoreState *first* causes the configuration file in KConfigGroup above (which has *nothing* to do with restoreState)
+  // to reset its Width and Height settings to what seem to be default values.
+  //
+  // I have no idea why this happens - restoreState doesn't trigger a saveProperties call so it shouldn't happen at all!
+  // It's dark magic, I tell you.
+  //
+  // Swapping the calls around fixes the problem. But again, I'll be damned if I can figure out
+  // what's going on.
+
   restoreWindowSize( group );
+  
+  restoreState( state );
 
   // Read if the spelling check feature is enabled
   toggleSpellCheck( group.readEntry( "UseSpellCheck", false ) );
@@ -1432,6 +1454,11 @@ void ChatWindow::saveProperties( KConfigGroup &config )
 
   group.writeEntry( "MessageSplitterSizes", splitter_->sizes()            );
   group.writeEntry( "CurrentZoom",          zoomLevel_                         );
+
+  // Save window size
+  saveWindowSize( group );
+
+  group.config()->sync();
 }
 
 
@@ -2257,7 +2284,8 @@ void ChatWindow::slotSwitchEditor()
   standardEmoticonsWidget_->hide();
   customEmoticonsWidget_->hide();
   winksWidget_->hide();
-
+  inkCanvas_->hide();
+  
   // Show the text control frame by default
   inkCtlFrame_->setVisible( false );
   textCtlFrame_->setVisible( true );
@@ -2287,6 +2315,8 @@ void ChatWindow::slotSwitchEditor()
 #ifdef KMESSDEBUG_CHATWINDOW
     kDebug() << "Switching to ink editor.";
 #endif
+    inkCanvas_->show();
+
     editorChooser_->setCurrentWidget( inkPage_ );
     winksButton_->setChecked( false );
     inkButton_->setChecked( true );
@@ -2484,6 +2514,11 @@ void ChatWindow::slotTabChanged( int currentIndex )
   setWindowTitle();
   updateModeButtons();
   slotGotTypingMessage( chat );
+
+  // Re-enable the spell checker for this tab.
+  // FIXME KDE4.x bug this needs to be unset then set
+  messageEdit_->setCheckSpellingEnabled( ! spellCheckAction_->isChecked() );
+  messageEdit_->setCheckSpellingEnabled( spellCheckAction_->isChecked() );
 }
 
 
@@ -2669,7 +2704,9 @@ void ChatWindow::toggleSpellCheck( bool useSpellCheck )
   }
 
   // Change the spell checking feature status
-  messageEdit_->setCheckSpellingEnabled( useSpellCheck );
+  // FIXME KDE4.x bug this needs to be unset then set
+  messageEdit_->setCheckSpellingEnabled( ! spellCheckAction_->isChecked() );
+  messageEdit_->setCheckSpellingEnabled( spellCheckAction_->isChecked() );
 }
 
 
