@@ -18,6 +18,7 @@
 #include "contactframe.h"
 
 #include "../contact/contact.h"
+#include "../contact/contactextension.h"
 #include "../contact/msnstatus.h"
 #include "../dialogs/contactpropertiesdialog.h"
 #include "../model/contactlist.h"
@@ -119,6 +120,9 @@ void ContactFrame::activate( ContactBase *contact )
     handle_  = contact_->getHandle();
     detailedContact_ = CurrentAccount::instance()->getContactList()->getContactByHandle( handle_ );
 
+    // ensure we know when the contact is now invalid.
+    connect( contact_, SIGNAL( destroyed(QObject*) ), this, SLOT( contactDestroyed(QObject*) ) );
+    
     if( detailedContact_ != 0 )
     {
       // Connect the contact, to update the frame on presence info changes
@@ -132,8 +136,6 @@ void ContactFrame::activate( ContactBase *contact )
                this,             SLOT  (          updatePicture()         ) );
       connect( detailedContact_, SIGNAL( changedPersonalMessage(Contact*) ),
                this,             SLOT  (    updateStatusWidgets()         ) );
-      connect( detailedContact_, SIGNAL(              destroyed(QObject*) ),
-               this,             SLOT  (       contactDestroyed(QObject*) ) );
     }
   }
 
@@ -185,6 +187,10 @@ void ContactFrame::contactDestroyed( QObject *object )
   // - somehow a code paths leads to this class (Chat::setSwitchboardConnection(0) is already patched).
   //   - crash.
 
+  // adam (17 Jan 2010) - the problem above occurs with InvitedContacts. we attach to the detailedContact_ destroyed() signal
+  // rather than the contact_ destroyed() signal. InvitedContact's have detailedContact_ == 0 so we never get notified
+  // of the InvitedContact deletion. fixed.
+
 #ifdef KMESSDEBUG_CONTACTFRAME
   if( contact_ && contact_ != object )
   {
@@ -244,22 +250,72 @@ bool ContactFrame::eventFilter( QObject *obj, QEvent *event )
   int eventType = event->type();
 
   // Check if the obj is contactPixmapLabel
-  if( obj == contactPixmapLabel_ && detailedContact_
-  && ( eventType == QEvent::Enter || eventType == QEvent::Leave ) )
+  if( obj == contactPixmapLabel_ && detailedContact_ )
   {
-    QImage image( detailedContact_->getContactPicturePath() );
-
     // Apply glow effect to image
     if( eventType == QEvent::Enter )
     {
+      QImage image( detailedContact_->getContactPicturePath() );
       KIconEffect::toGamma( image, 0.8f );
       contactPixmapLabel_->setPixmap( QPixmap::fromImage( image ) );
     }
     else if( eventType == QEvent::Leave && !typingTimer_.isActive() )
     {
+      QImage image( detailedContact_->getContactPicturePath() );
+      
       // Only disable glow effect when the contact is not typing
       contactPixmapLabel_->setPixmap( QPixmap::fromImage( image ) );
     }
+    else if ( eventType == QEvent::DragEnter )
+    {
+      QDragEnterEvent *dragEvent = static_cast<QDragEnterEvent*>( event );
+      const QMimeData *mimeData = dragEvent->mimeData();
+
+      // The mimeData object can contain one of the following objects: an image, HTML text, plain text, or a list of URLs.
+      // We need only the first URL object
+      if( mimeData->hasUrls() )
+      {
+        dragEvent->acceptProposedAction();
+      }
+      else
+      {
+        dragEvent->ignore();
+      }
+    }
+    else if ( eventType == QEvent::Drop )
+    {
+      QDropEvent* dropEvent = static_cast<QDropEvent*>( event );
+      const QMimeData *mimeData = dropEvent->mimeData();
+
+      // The mimeData object can contain one of the following objects: an image, HTML text, plain text, or a list of URLs.
+      // We need only the first URL object
+      if( ! mimeData->hasUrls() )
+      {
+        return true;
+      }
+
+      QUrl mimeUrl = mimeData->urls().first();
+      QString filePath;
+      QPixmap pictureData;
+
+      if( mimeUrl.isEmpty() )
+      {
+        kWarning() << "Dropped empty MIME URL";
+        return true;
+      }
+
+      filePath = mimeUrl.path();
+
+      if( ! pictureData.load( filePath ) )
+      {
+        kWarning() << "The file dropped is not an image or doesn't exist";
+        return true;
+      }
+
+      detailedContact_->getExtension()->setContactAlternativePicturePath( filePath );
+
+      dropEvent->acceptProposedAction();
+    }
   }
 
   if( eventType != QEvent::MouseButtonRelease )
@@ -731,12 +787,6 @@ void ContactFrame::updatePicture()
 
   // Display the image
   contactPixmapLabel_->setPixmap( contactPicture_ );
-
-  // only change min size for images smaller than 96x96
-  if ( contactImage.width() < 96 && contactImage.height() < 96 )
-  {
-    contactPixmapLabel_->setMinimumSize( contactImage.width(), contactImage.height() );
-  }
 }
 
 
