@@ -21,7 +21,10 @@
 #include "../chat/chatmessageview.h"
 #include "../utils/kmessconfig.h"
 #include "../utils/kmessshared.h"
+#include "../accountsmanager.h"
 #include "../currentaccount.h"
+#include "../kmess.h"
+#include "../kmessapplication.h"
 #include "../kmessdebug.h"
 
 #include <QDir>
@@ -54,7 +57,8 @@ ChatHistoryDialog::ChatHistoryDialog( QWidget *parent )
 , model_( new QStandardItemModel( this ) )
 , proxyModel_( new QSortFilterProxyModel( this ) )
 , reloadingLogs_( false )
-, reloadLogsTimer_(0)
+, reloadLogsTimer_( 0 )
+, historyAccount_( 0 )
 {
   // Set up the dialog
   QWidget *mainWidget = new QWidget( this );
@@ -87,6 +91,40 @@ ChatHistoryDialog::ChatHistoryDialog( QWidget *parent )
   chatView_->widget()->setMinimumSize( 300, 200 );
   chatView_->widget()->setSizePolicy( sizePolicy );
 
+  // When we are not connected, there is no set chat style. Use the default
+//   if( Account::connectedAccount == 0 )
+  {
+//     chatView_->getStyle()->setStyle( "Fresh" );
+  }
+
+  // Fill the accounts list
+  handleComboBox_->insertItems( 0, KMessConfig::instance()->getAccountsList() );
+
+  // If no accounts are available, disable the dialog
+  if( handleComboBox_->count() == 0 )
+  {
+    mainWidget->setEnabled( false );
+  }
+  else
+  {
+    KMessApplication *kmessApp = static_cast<KMessApplication*>( kapp );
+
+    // When disconnected or using a guest account, the accounts list will default to the
+    // first available account
+    if( ! kmessApp->getContactListWindow()->isConnected()
+    ||    CurrentAccount::instance()->isGuestAccount() )
+    {
+      const QString &currentHandle( handleComboBox_->itemText( 0 ) );
+      historyAccount_ = AccountsManager::instance()->getAccountByHandle( currentHandle );
+      handleComboBox_->setCurrentItem( currentHandle );
+    }
+    else
+    {
+      historyAccount_ = CurrentAccount::instance();
+      handleComboBox_->setCurrentItem( historyAccount_->getHandle() );
+    }
+  }
+
   loadContactsList();
 
   // Initialize the model for the list of contacts
@@ -99,24 +137,26 @@ ChatHistoryDialog::ChatHistoryDialog( QWidget *parent )
   QItemSelectionModel *selectionModel = listView_->selectionModel();
 
   // Attach the signals
-  connect( searchEdit_,           SIGNAL(       textChanged(const QString&)                     ),
-           proxyModel_,           SLOT  (         setFilterRegExp(const QString&)               ) );
-  connect( selectionModel,        SIGNAL( currentChanged(const QModelIndex&,const QModelIndex&) ),
-           this,                  SLOT  (         cacheContactXml(const QModelIndex&)           ) );
-  connect( dateRadio_,            SIGNAL(       toggled(bool)                                   ),
-           this,                  SLOT  (         reloadLogs()                                  ) );
-  connect( fromBox_,              SIGNAL(       toggled(bool)                                   ),
-           this,                  SLOT  (         reloadLogs()                                  ) );
-  connect( toBox_,                SIGNAL(       toggled(bool)                                   ),
-           this,                  SLOT  (         reloadLogs()                                  ) );
-  connect( fromDate_,             SIGNAL(       changed(const QDate&)                           ),
-           this,                  SLOT  (         checkDates()                                  ) );
-  connect( toDate_,               SIGNAL(       changed(const QDate&)                           ),
-           this,                  SLOT  (         checkDates()                                  ) );
-  connect( conversationRadio_,    SIGNAL(       toggled(bool)                                   ),
-           this,                  SLOT  (         reloadLogs()                                  ) );
-  connect( conversationComboBox_, SIGNAL(       currentIndexChanged(int)                        ),
-           this,                  SLOT  (         reloadLogs()                                  ) );
+  connect( searchEdit_,           SIGNAL(         textChanged(const QString&)                        ),
+           proxyModel_,           SLOT  (     setFilterRegExp(const QString&)                        ) );
+  connect( selectionModel,        SIGNAL(      currentChanged(const QModelIndex&,const QModelIndex&) ),
+           this,                  SLOT  (     cacheContactXml(const QModelIndex&)                    ) );
+  connect( dateRadio_,            SIGNAL(             toggled(bool)                                  ),
+           this,                  SLOT  (          reloadLogs()                                      ) );
+  connect( fromBox_,              SIGNAL(             toggled(bool)                                  ),
+           this,                  SLOT  (          reloadLogs()                                      ) );
+  connect( toBox_,                SIGNAL(             toggled(bool)                                  ),
+           this,                  SLOT  (          reloadLogs()                                      ) );
+  connect( fromDate_,             SIGNAL(             changed(const QDate&)                          ),
+           this,                  SLOT  (          checkDates()                                      ) );
+  connect( toDate_,               SIGNAL(             changed(const QDate&)                          ),
+           this,                  SLOT  (          checkDates()                                      ) );
+  connect( conversationRadio_,    SIGNAL(             toggled(bool)                                  ),
+           this,                  SLOT  (          reloadLogs()                                      ) );
+  connect( conversationComboBox_, SIGNAL( currentIndexChanged(int)                                   ),
+           this,                  SLOT  (          reloadLogs()                                      ) );
+  connect( handleComboBox_,       SIGNAL( currentIndexChanged(int)                                   ),
+           this,                  SLOT  (        reloadHandle(int)                                   ) );
 
   // Register QDomElement as a meta type to allow the thread to send signals here
   qRegisterMetaType<QDomElement>( "QDomElement" );
@@ -198,6 +238,11 @@ void ChatHistoryDialog::addConversation( int timestamp, const QDomElement &newCo
 // Caches the XML for the selected contact. Makes things a lot faster
 void ChatHistoryDialog::cacheContactXml( const QModelIndex &index )
 {
+  if( historyAccount_ == 0 )
+  {
+    return;
+  }
+
   const QModelIndex contactIndex( proxyModel_->mapToSource( index ) );
   if( ! contactIndex.isValid() )
   {
@@ -227,7 +272,7 @@ void ChatHistoryDialog::cacheContactXml( const QModelIndex &index )
   QDomNode cachedConversations( xml_.firstChildElement( "conversations" ) );
 
   const QString handle( model_->itemFromIndex( contactIndex )->text() );
-  QDir logsDir( KMessConfig::instance()->getAccountDirectory( CurrentAccount::instance()->getHandle() )
+  QDir logsDir( KMessConfig::instance()->getAccountDirectory( historyAccount_->getHandle() )
                 + "/chatlogs" );
 
 #ifdef KMESSDEBUG_CHATHISTORYDIALOG
@@ -372,8 +417,16 @@ bool ChatHistoryDialog::checkDates( bool checkAndReloadLogs )
 // Load the list of contacts for which logs are available
 void ChatHistoryDialog::loadContactsList()
 {
+  // Clear the list
+  model_->clear();
+
+  if( historyAccount_ == 0 )
+  {
+    return;
+  }
+
   // Find all XML chat log files in the logs directory
-  QDir logsDir( KMessConfig::instance()->getAccountDirectory( CurrentAccount::instance()->getHandle() )
+  QDir logsDir( KMessConfig::instance()->getAccountDirectory( historyAccount_->getHandle() )
                 + "/chatlogs" );
 
   logsDir.setFilter( QDir::Files );
@@ -404,6 +457,17 @@ void ChatHistoryDialog::loadContactsList()
 
 
 
+// Change the account for which to show logs
+void ChatHistoryDialog::reloadHandle( int index )
+{
+  const QString &handle( handleComboBox_->itemText( index ) );
+
+  historyAccount_ = AccountsManager::instance()->getAccountByHandle( handle );
+  loadContactsList();
+}
+
+
+
 // Reload the current chat log history
 void ChatHistoryDialog::reloadLogs()
 {
@@ -804,4 +868,6 @@ void ChatHistoryDialog::slotShowContextMenu( const QString &clickedUrl, const QP
   delete popup;
 }
 
+
+
 #include "chathistorydialog.moc"
