@@ -398,7 +398,9 @@ void ContactPropertiesDialog::setupWidgets()
   {
     lastSeenString = i18n( "Connected" );
   }
-  else if( extension->getLastSeen().toTime_t() == 0 || extension->getLastSeen().isNull() )
+  else if( extension->getLastSeen().toTime_t() == 0
+            || extension->getLastSeen().toTime_t() == UINT_MAX
+            || extension->getLastSeen().isNull() )
   {
     lastSeenString = i18n( "Not seen yet" );
   }
@@ -407,7 +409,9 @@ void ContactPropertiesDialog::setupWidgets()
     lastSeenString = extension->getLastSeen().toString();
   }
 
-  if( extension->getLastMessageDate().toTime_t() == 0 || extension->getLastMessageDate().isNull() )
+  if( extension->getLastMessageDate().toTime_t() == 0
+       || extension->getLastMessageDate().toTime_t() == UINT_MAX
+       || extension->getLastMessageDate().isNull() )
   {
     lastMessageString = i18n( "No messages yet" );
   }
