@@ -628,22 +628,12 @@ bool EmoticonTheme::saveTheme()
     return false;
   }
 
-  // Get encoding
-  QTextCodec *codec = QTextCodec::codecForLocale();
-  if( codec == 0 )
-  {
-    kWarning() << "Could not find codec '" << QTextCodec::codecForLocale() << "', special characters might not be saved correctly!";
-  }
-
-  // Start the XML output using the right text encoding
+  QTextCodec *codec = QTextCodec::codecForName("UTF-8");
   QTextStream xmlOutput( &xmlFile );
-  if( codec != 0 )
-  {
-    xmlOutput.setCodec( codec );
-  }
-
+  xmlOutput.setCodec( codec );
+  
   // Start the XML tree by writing the root tag
-  xmlOutput << "<?xml version=\"1.0\"?>" << endl << "<messaging-emoticon-map>" << endl << endl;
+  xmlOutput << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << endl << "<messaging-emoticon-map>" << endl << endl;
 
   foreach( Emoticon *emoticon, emoticons_ )
   {
