@@ -459,7 +459,10 @@ void KMess::changedSong( const QString &artist, const QString &album, const QStr
     }
 
     // Update KMessView
-    view_->changedSong( artist, album, track, playing );
+    if( view_ )
+    {
+        view_->changedSong( artist, album, track, playing );
+    }
   }
 }
 
@@ -851,13 +854,6 @@ void KMess::connectWithAccount(Account *account)
   kDebug() << "Connecting account:" << account->getHandle();
 #endif
 
-  // Update the initial view with account details and start the connection if everything is ok
-  if( ! initialView_->startConnecting( account->getHandle(), false /* emitConnectionSignal */ ) )
-  {
-    show();
-    return;
-  }
-
   startConnection( account );
 }
 
@@ -1824,6 +1820,13 @@ void KMess::startConnection( Account *account )
     msnNotificationConnection_->closeConnection();
   }
 
+  // Update the initial view with account details and start the connection if everything is ok
+  if( ! initialView_->startConnecting( account->getHandle(), false /* emitConnectionSignal */ ) )
+  {
+    show();
+    return;
+  }
+
   // Update the main view's controls to match this account's details.
   changedStatus( account );
 
@@ -1880,6 +1883,8 @@ void KMess::switchViewToContactList()
            msnNotificationConnection_, SLOT  (  allowContact(QString)                   ) );
   connect( view_,                      SIGNAL(  blockContact(QString)                   ),   // Block the contact
            msnNotificationConnection_, SLOT  (  blockContact(QString)                   ) );
+  connect( view_,                      SIGNAL( changeFriendlyName(QString)              ),   // Change the friendly name
+           msnNotificationConnection_, SLOT  ( changeFriendlyName(QString)              ) );
   connect( view_,                      SIGNAL( changePersonalMessage(QString)           ),   // Change the personal message.
            msnNotificationConnection_, SLOT  ( changePersonalMessage(QString)           ) );
   connect( view_,                      SIGNAL(       copyContact(QString, QString)      ),
