@@ -381,7 +381,7 @@ bool KMessInterface::initialize()
   createMenus();
 
   // Build the gui from xml (without toolbar support)
-  setupGUI( ( Keys | StatusBar | Create | Save ), "kmessinterfaceui.rc" );
+  setupGUI( ( Keys | Create | Save ), "kmessinterfaceui.rc" );
 
   // Autosave all GUI settings
 #if KDE_IS_VERSION(4,0,70)
