@@ -48,6 +48,7 @@
 #include <KActionMenu>
 #include <KApplication>
 #include <KGlobal>
+#include <KIO/NetAccess>
 #include <KIconLoader>
 #include <KIconEffect>
 #include <KLocale>
@@ -85,20 +86,17 @@ KMessView::KMessView( QWidget *parent )
   searchFrame_->hide();
 
   // Capture focus events without subclassing the widget from the .UI file
-  personalMessageInput_->installEventFilter(this);
   currentAccountDisplayPic_->installEventFilter(this);
   contactListView_->installEventFilter(this);
   contactListView_->viewport()->installEventFilter(this);
 
-  // Fake an event to configure the personal message input
-  QEvent ev(QEvent::FocusOut);
-  eventFilter(personalMessageInput_, &ev);
-
   // Windows Live Messenger 8.5 and 2009 (latter only in the chat screen) don't
   // display any part further than 129 characters.
-  // TODO: allow further than 129, but display a warning while typing.
   personalMessageInput_->setMaxLength( 129 );
 
+  friendlyNameInput_->setFormattingMode( STRING_LIST_SETTING );
+  personalMessageInput_->setFormattingMode( STRING_LIST_SETTING );
+
   // Set up the group update timer
   updateTimer_.setSingleShot( true );
   connect( &updateTimer_, SIGNAL(          timeout() ),
@@ -125,7 +123,7 @@ KMessView::~KMessView()
   delete viewModel_;
   selectionModel_ = 0;
   viewModel_ = 0;
-  
+
 #ifdef KMESSDEBUG_KMESSVIEW_GENERAL
   kDebug() << "DESTROYED.";
 #endif
@@ -273,11 +271,12 @@ bool KMessView::initialize( QAbstractItemModel *viewModel )
            statusButton_, SLOT  (     showMenu()         ) );
 
   // Enable the labels
-  onlineStatusLabel_->setEnabled(true);
   emailLabel_->setEnabled(true);
 
   QFont appFont( QApplication::font() );
-  onlineStatusLabel_->setStyleSheet( "QLabel { font-size: " + QString::number( appFont.pointSize() + 2 )  + "pt; }" );
+  int appFontSize = appFont.pointSize();
+  friendlyNameInput_->setStyleSheet( "QLabel { font-size: " + QString::number( appFontSize + 2 )  + "pt; }" );
+  personalMessageInput_->setStyleSheet( "QLabel { font-size: " + QString::number( appFontSize - 1 )  + "pt; }" );
 
   // Hide the now listening until something is playing
   changedSong( QString(), QString(), QString(), false );
@@ -291,6 +290,8 @@ bool KMessView::initialize( QAbstractItemModel *viewModel )
            this,            SLOT  (        slotUpdateUserStatus() ) );
   connect( currentAccount_, SIGNAL(         changedFriendlyName() ),    // Changed name
            this,            SLOT  (        slotUpdateUserStatus() ) );
+  connect( currentAccount_, SIGNAL(      changedPersonalMessage() ),    // Changed personal message
+           this,            SLOT  (        slotUpdateUserStatus() ) );
   connect( currentAccount_, SIGNAL( changedEmailDisplaySettings() ),    // Changed email display settings
            this,            SLOT  (      slotUpdateEmailDisplay() ) );
   connect( currentAccount_, SIGNAL(      changedDisplaySettings() ),
@@ -299,6 +300,8 @@ bool KMessView::initialize( QAbstractItemModel *viewModel )
            this,            SLOT  (            slotUpdateGroups() ) );
   connect( currentAccount_, SIGNAL(   changedContactListOptions() ),     // Changed contact list options
            this,            SLOT  (              slotUpdateView() ) );
+  connect( currentAccount_, SIGNAL(   changedContactListOptions() ),     // Changed contact list options
+           this,            SLOT  (        slotUpdateUserStatus() ) );
   // These update the display pic size depending on the email & now listening options
   connect( currentAccount_, SIGNAL( changedNowListeningSettings() ),
            this,            SLOT  (    slotUpdateDisplayPicture() ) );
@@ -326,6 +329,11 @@ bool KMessView::initialize( QAbstractItemModel *viewModel )
 
   historyBox_->insertItem( 0, i18n( "[%1] Logged in with %2", QTime::currentTime ().toString( "HH:mm:ss" )
                                                          , currentAccount_->getHandle() ) );
+  // Enable changing inline the friendly name and PM
+  connect( friendlyNameInput_,    SIGNAL(               changed() ),
+           this,                  SLOT  (    updateFriendlyName() ) );
+  connect( personalMessageInput_, SIGNAL(               changed() ),
+           this,                  SLOT  ( updatePersonalMessage() ) );
 
   // Connect the search edit line with slot for searching
   connect( searchEdit_, SIGNAL(       textChanged(QString) ),
@@ -343,7 +351,9 @@ bool KMessView::initialize( QAbstractItemModel *viewModel )
   slotUpdateNoEmails();
   slotUpdateDisplayPicture();
   slotUpdateGroups();
-  slotPersonalMessageLostFocus( true );
+
+  updateFriendlyName( true );
+  updatePersonalMessage( true );
 
   return true;
 }
@@ -431,8 +441,7 @@ void KMessView::toggleShowSearchFrame( bool show )
 // The personal status message received an event.
 bool KMessView::eventFilter(QObject *obj, QEvent *event)
 {
-  if( obj != personalMessageInput_
-  &&  obj != currentAccountDisplayPic_
+  if(obj != currentAccountDisplayPic_
   &&  obj != contactListView_
   &&  obj != contactListView_->viewport() )
   {
@@ -460,6 +469,120 @@ bool KMessView::eventFilter(QObject *obj, QEvent *event)
     {
       emit showSettings();
     }
+    else if( eventType == QEvent::DragEnter )
+    {
+      QDragEnterEvent *dragEvent = static_cast<QDragEnterEvent*>( event );
+      const QMimeData *mimeData = dragEvent->mimeData();
+
+      // The mimeData object can contain one of the following objects: an image, HTML text, plain text, or a list of URLs.
+      // We need only the first URL object
+      if( mimeData->hasUrls() )
+      {
+        dragEvent->acceptProposedAction();
+      }
+      else
+      {
+        dragEvent->ignore();
+      }
+    }
+    else if( eventType == QEvent::Drop )
+    {
+      QDropEvent* dropEvent = static_cast<QDropEvent*>( event );
+      const QMimeData *mimeData = dropEvent->mimeData();
+
+      // The mimeData object can contain one of the following objects: an image, HTML text, plain text, or a list of URLs.
+      // We need only the first URL object
+      if( ! mimeData->hasUrls() )
+      {
+        return true;
+      }
+      else
+      {
+        KUrl mimeUrl = mimeData->urls().first();
+        bool isRemoteFile = false;
+        QString localFilePath;
+        QImage  pictureData;
+
+        if( mimeUrl.isEmpty() )
+        {
+          kWarning() << "Dropped empty MIME URL";
+          return true;
+        }
+
+        if( mimeUrl.isLocalFile() )
+        {
+          localFilePath = mimeUrl.path();
+        }
+        else
+        {
+          // File is remote, download it to a local folder
+          // first because QPixmap doesn't have KIO magic.
+          // KIO::NetAccess::download fills the localFilePath field.
+          if( ! KIO::NetAccess::download(mimeUrl, localFilePath, this ) )
+          {
+            KMessageBox::sorry( this, i18n( "Downloading of display picture failed" ), i18n("KMess") );
+
+            return true;
+          }
+
+          isRemoteFile = true;
+        }
+
+        if( ! pictureData.load( localFilePath ) )
+        {
+          kWarning() << "The file dropped is not an image or doesn't exist";
+          return true;
+        }
+
+        if( isRemoteFile )
+        {
+          KIO::NetAccess::removeTempFile( localFilePath );
+        }
+
+        pictureData = pictureData.scaled( 96, 96, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation ); // Makes smallest edge 96 pixels, preserving aspect ratio
+
+        if( pictureData.width() != 96 || pictureData.height() != 96 )
+        {
+          // Copy the middle part of the picture.
+          pictureData = pictureData.copy( (pictureData.width() - 96) / 2,  // X
+                                          (pictureData.height() - 96) / 2, // Y
+                                          96, 96 );
+        }
+
+        QString pictureDir = KMessConfig::instance()->getAccountDirectory( currentAccount_->getHandle() ) + "/displaypics/";
+        QString tempPictureFile = pictureDir + "temporary-picture.png";
+
+        if( ! pictureData.save( tempPictureFile, "PNG" ) )
+        {
+          KMessageBox::sorry( this,
+                              i18n( "An error occurred while trying to change the display picture.\n"
+                                    "Make sure that you have selected an existing image file." ),
+                              i18n( "KMess" ) );
+        }
+
+        QString msnObjectHash( KMessShared::generateFileHash( tempPictureFile ).toBase64() );
+        const QString safeMsnObjectHash( msnObjectHash.replace( QRegExp("[^a-zA-Z0-9+=]"), "_" ) );
+
+        // Save the new display picture with its hash as name, to ensure correct caching
+        QString pictureName = msnObjectHash + ".png";
+        QDir pictureFolder = QDir( pictureDir );
+
+        // Do not overwrite identical pictures
+        if( ! pictureFolder.exists( pictureName ) )
+        {
+          if( ! pictureFolder.rename( tempPictureFile, pictureName ) )
+          {
+            kWarning() << "The display picture file could not be renamed from" << tempPictureFile << "to" << pictureName << ".";
+            return true;
+          }
+        }
+
+        currentAccount_->setPicturePath( pictureDir + pictureName );
+        currentAccount_->setOriginalPicturePath( mimeUrl.path() );
+
+        dropEvent->acceptProposedAction();
+      }
+    }
   }
   else if( obj == contactListView_->viewport() )
   {
@@ -488,44 +611,6 @@ bool KMessView::eventFilter(QObject *obj, QEvent *event)
       }
     }
   }
-  else if( obj == personalMessageInput_ )
-  {
-    if( eventType == QEvent::Enter )
-    {
-      // Mouse enters widget's boundaries
-      // Just a bit different from the original client, already change the background line web-forms also do.
-      personalMessageInput_->setStyleSheet( "QLineEdit{ background-color: base; }" );
-    }
-    else if( eventType == QEvent::Leave )
-    {
-      // Mouse leaves the widget.
-      if( ! personalMessageInput_->hasFocus() )
-      {
-        personalMessageInput_->setStyleSheet( "QLineEdit{ background-color: transparent; }" );
-      }
-    }
-    else if( eventType == QEvent::FocusIn )
-    {
-      // Personal status mesage got the focus
-      personalMessageInput_->setStyleSheet( "QLineEdit{ background-color: base; }" );
-
-      // Clear if there is no status message, but a placeholder label
-      if( currentAccount_->getPersonalMessage().isEmpty() )
-      {
-        personalMessageInput_->clear();
-      }
-      else
-      {
-        // Select all text for editing
-        personalMessageInput_->selectAll();
-      }
-    }
-    else if( event->type() == QEvent::FocusOut )
-    {
-      // Lost the focus
-      personalMessageInput_->setStyleSheet( "QLineEdit{ background-color: transparent; }" );
-    }
-  }
 
   return false;  // don't stop processing.
 }
@@ -1204,7 +1289,9 @@ void KMessView::showToolTip( const QPoint &point )
       {
         lastSeenString = i18n( "Connected" );
       }
-      else if( lastSeen.toTime_t() == 0 || lastSeen.isNull() )
+      else if( lastSeen.toTime_t() == 0
+                || lastSeen.toTime_t() == UINT_MAX
+                || lastSeen.isNull() )
       {
         lastSeenString = i18n( "Not seen yet" );
       }
@@ -1219,7 +1306,9 @@ void KMessView::showToolTip( const QPoint &point )
       // Add last message date
       const QDateTime& lastMessage( itemData[ "lastMessage" ].toDateTime() );
       QString lastMessageString;
-      if( lastMessage.toTime_t() == 0 || lastMessage.isNull() )
+      if( lastMessage.toTime_t() == 0
+          || lastMessage.toTime_t() == UINT_MAX
+          || lastMessage.isNull() )
       {
         lastMessageString = i18n( "No messages yet" );
       }
@@ -1663,30 +1752,81 @@ void KMessView::slotForwardUnblockContact()
 
 
 
-// Called when the enter key is pressed on the personal message input
-void KMessView::slotPersonalMessageEnterPressed()
+/**
+ * @brief Update the friendly name from the inline editing label.
+ *
+ * Sends to the server the new friendly name selected by clicking
+ * the friendly name inline editing label.
+ *
+ * @param refreshOnly  When true, the FN widget is only updated with the
+ *                     current account's name. When false, it is updated
+ *                     with the default message, and nothing is sent to
+ *                     the server.
+ */
+void KMessView::updateFriendlyName( bool refreshOnly )
 {
-  personalMessageInput_->clearFocus();
+  const QString& defaultTooltip( i18nc( "Default friendly name tooltip", "Click here to change your friendly name" ) );
+  const QString& defaultName( currentAccount_->getFriendlyName( STRING_ORIGINAL ).trimmed() );
+
+  // When refreshing the message or when the focus losing isn't voluntary, don't update it on the server
+  if( refreshOnly || ! isActiveWindow() || ! topLevelWidget()->isActiveWindow() )
+  {
+#ifdef KMESSDEBUG_KMESSVIEW_GENERAL
+    kDebug() << "Refreshing name only: initial update or non-intentional focus lose.";
+#endif
+
+    // Refresh the message
+    friendlyNameInput_->setToolTip( defaultTooltip );
+    friendlyNameInput_->setText( defaultName );
+    return;
+  }
+
+  // Get message
+  QString newName( friendlyNameInput_->text().trimmed() );
+
+#ifdef KMESSDEBUG_KMESSVIEW_GENERAL
+  kDebug() << "Updating friendly name to:" << newName;
+#endif
+
+  // Set a default name (the email address) if the field is left empty
+  if( newName.isEmpty() )
+  {
+    newName = currentAccount_->getHandle();
+  }
+
+  // Only update the name if it's been changed
+  if( defaultName == newName )
+  {
+    return;
+  }
+
+  // Update the name and save the changes
+  currentAccount_->setFriendlyName( newName );
+  friendlyNameInput_->setToolTip( newName );
+  // Commit changes to disk, now
+  currentAccount_->saveProperties();
+
+  // Notify changes to the MSN server
+  emit changeFriendlyName( newName );
 }
 
 
 
 /**
- * @brief Called when the personal message input looses focus
+ * @brief Update the personal message from the inline editing label.
  *
- * Sends to the server the new personal message selected by the user.
+ * Sends to the server the new personal message selected by clicking
+ * the personal message inline editing label.
  *
  * @param refreshOnly  When true, the PM widget is only updated with the
- *                     current account's message, or with the default
- *                     message, and nothing is sent to the server.
+ *                     current account's message. When false, it is updated
+ *                     with the default message, and nothing is sent to
+ *                     the server.
  */
-void KMessView::slotPersonalMessageLostFocus( bool refreshOnly )
+void KMessView::updatePersonalMessage( bool refreshOnly )
 {
-  const QString& defaultMessage( i18nc( "Default personal message shown in the contact list", "&lt;Enter your personal message here&gt;" ) );
-  const QString& defaultTooltip( i18nc( "Default personal message tooltip", "Enter here a message to show to your contacts: they will see it along with your friendly name" ) );
-
-  personalMessageInput_->clearFocus();
-  contactListView_->setFocus();
+  const QString& defaultMessage( i18nc( "Default personal message shown in the contact list", "[i]Click to set a personal message[/i]" ) );
+  const QString& defaultTooltip( i18nc( "Default personal message tooltip", "Click here to insert a message to show to your contacts: they will see it along with your friendly name" ) );
 
   // When refreshing the message or when the focus losing isn't voluntary, don't update it on the server
   if( refreshOnly || ! isActiveWindow() || ! topLevelWidget()->isActiveWindow() )
@@ -1696,11 +1836,11 @@ void KMessView::slotPersonalMessageLostFocus( bool refreshOnly )
 #endif
 
     // Refresh the message
-    const QString &message( currentAccount_->getPersonalMessage( STRING_ORIGINAL ) );
+    const QString &message( currentAccount_->getPersonalMessage( STRING_ORIGINAL ).trimmed() );
     if( message.isEmpty() )
     {
       personalMessageInput_->setToolTip( defaultTooltip );
-      personalMessageInput_->setText( defaultMessage );
+      personalMessageInput_->setText( defaultMessage, true );
     }
     else
     {
@@ -1708,15 +1848,11 @@ void KMessView::slotPersonalMessageLostFocus( bool refreshOnly )
       personalMessageInput_->setText( message );
     }
 
-    personalMessageInput_->setCursorPosition(0);
-
     return;
   }
 
-  personalMessageInput_->setCursorPosition(0);
-
   // Get message
-  const QString& message( personalMessageInput_->text() );
+  const QString& message( personalMessageInput_->text().trimmed() );
 
 #ifdef KMESSDEBUG_KMESSVIEW_GENERAL
   kDebug() << "Updating personal message to:" << message;
@@ -1747,7 +1883,7 @@ void KMessView::slotPersonalMessageLostFocus( bool refreshOnly )
   if( message.isEmpty() )
   {
     personalMessageInput_->setToolTip( defaultTooltip );
-    personalMessageInput_->setText( defaultMessage );
+    personalMessageInput_->setText( defaultMessage, true );
   }
 }
 
@@ -2088,15 +2224,15 @@ void KMessView::slotUpdateUserStatus()
 {
   const Status status( currentAccount_->getStatus() );
 
-  // Avoid newlines, which cause problems to the layout.
-  QString friendlyName( currentAccount_->getFriendlyName( STRING_LIST_SETTING_ESCAPED ).replace( '\n', ' ' ) );
-
 #ifdef KMESSDEBUG_KMESSVIEW_GENERAL
   kDebug() << "Updating user status to:" << MsnStatus::getName( status );
 #endif
 
   // Update the widgets
-  onlineStatusLabel_->setText( friendlyName );
+
+  updateFriendlyName( true );
+  updatePersonalMessage( true );
+
   statusButton_->setText( MsnStatus::getName( status ) );
   statusButton_->setIcon( MsnStatus::getIcon( status ) );
 }
