@@ -268,7 +268,8 @@ void KMessViewDelegate::paint( QPainter *painter, const QStyleOptionViewItem &op
   if(   itemData[ "type" ].toInt() == ContactListModelItem::ItemContact
   &&  ! itemData[ "isReverse" ].toBool() ) // The contact does not have us in its list
   {
-    painter->fillRect( option.rect, QColor( 255,0,0,20 ) );
+    // TODO: fontknocker (19 Feb 10): re-enable this when we get our list memberships sorted out.
+    //painter->fillRect( option.rect, QColor( 255,0,0,20 ) );
   }
 
   // Paint the images
