@@ -44,13 +44,13 @@ int main(int argc, char *argv[])
                         KMESS_VERSION,                             // app version from config-kmess.h
                         ki18n("A Live Messenger client for KDE"),  // short description
                         KAboutData::License_GPL,                   // license
-                        ki18n("(c) 2002-2009, Mike K. Bennett\n"   // copyright
-                              "(c) 2005-2009, Diederik van der Boor\n"
-                              "(c) 2007-2009, Valerio Pilo\n"
-                              "(c) 2008-2009, Antonio Nastasi\n"
-                              "(c) 2008-2009, Ruben Vandamme\n"
-                              "(c) 2009, Sjors Gielen\n"
-                              "(c) 2009, Adam Goossens\n"),
+                        ki18n("(c) 2002-2010, Mike K. Bennett\n"   // copyright
+                              "(c) 2005-2010, Diederik van der Boor\n"
+                              "(c) 2007-2010, Valerio Pilo\n"
+                              "(c) 2008-2010, Antonio Nastasi\n"
+                              "(c) 2008-2010, Ruben Vandamme\n"
+                              "(c) 2009-2010, Sjors Gielen\n"
+                              "(c) 2009-2010, Adam Goossens\n"),
                         KLocalizedString(),
                         "http://www.kmess.org/",                   // home page
                         "bugs" "@" "kmess" "." "org"               // address for bugs
@@ -88,7 +88,7 @@ int main(int argc, char *argv[])
   aboutData.addCredit( ki18n("Mauricio Rother"),           ki18n("Brazilian Portuguese translation"), "mauricio" "@" "digicomm" "." "com.br");
   aboutData.addCredit( ki18n("Leonel Freire"),             ki18n("More Brazilian Portuguese translation"), "leonelfreire" "@" "gmail" "." "com");
   aboutData.addCredit( ki18n("Sergio Rafael Lemke"),       ki18n("More Brazilian Portuguese translation"), "bedi" "." "com" "@" "gmail" "." "com");
-  aboutData.addCredit( ki18n("Maurício Arozi Moraes"),     ki18n("More Brazilian Portuguese translation"));
+  aboutData.addCredit( ki18n("Morris Arozi Moraes"),     ki18n("More Brazilian Portuguese translation"));
 
   aboutData.addCredit( ki18n("Jaume Cornadó"),             ki18n("Catalan translation"),              "jaumec" "@" "lleida" "." "net");
   aboutData.addCredit( ki18n("Adrià Arrufat"),             ki18n("More Catalan translation"),              "swiftscythe" "@" "gmail" "." "com");
@@ -179,6 +179,7 @@ int main(int argc, char *argv[])
   aboutData.addCredit( ki18n("David López"),               ki18n("Nudge button in chat"),            "grannost" "@" "gmail" "." "com" );
   aboutData.addCredit( ki18n("Pieterjan Camerlynck"),      ki18n("Roaming Service support"),         "pieterjan" "." "camerlynck" "@" "gmail" "." "com" );
   aboutData.addCredit( ki18n("Anastasios Bourazanis"),     ki18n("Emoticon preview in settings page,clickable contact properties dialog text"), "a.brzns" "@" "gmail" "." "com");
+  aboutData.addCredit( ki18n("Marco Mentasti"),            ki18n("Internationalization fixes, drag'n'drop of images into display pictures"), "marcomentasti" "@" "gmail" "." "com" );
 
   // Other apps
   aboutData.addCredit( ki18n("KMerlin (kmerlin.olsd.de)"), ki18n("Inspiration and assorted code"));
