@@ -451,7 +451,7 @@ void MsnConnection::parseError( const QStringList &command, const QByteArray &pa
       isWarning = true;
       break;
     case 229:
-      errorMessage = i18n("The group name is too long; it cannot be longer than 61 bytes");
+      errorMessage = i18n("The group name is too long; it cannot be longer than 61 characters");
       isWarning = true;
       break;
     case 230:
