@@ -26,8 +26,6 @@
 #include <QDateTime>
 #include <QList>
 #include <QTimer>
-#include <QtCrypto>
-
 
 
 
@@ -210,8 +208,8 @@ class MsnNotificationConnection : public MsnConnection
     // Create the passport login handler
     PassportLoginService *createPassportLoginService();
     // Create triple des encryption
-    QByteArray           createTripleDes ( const QByteArray key, const QByteArray secret,
-                                            const QCA::InitializationVector& iv );
+    QByteArray           createTripleDes ( const QByteArray &key, const QByteArray &secret,
+                                            const QByteArray &iv );
     // Received response to adl command
     void                 gotAdl( const QStringList& command, const QString &payload = "" );
     // Received confirmation of the user's status change
@@ -306,7 +304,7 @@ class MsnNotificationConnection : public MsnConnection
     AddressBookService   *addressBookService_;
     bool                 connected_;
     // Nonce received by the server on first SSO command
-    QString              nonceBase64_;
+    QByteArray           nonceBase64_;
     // The list of contacts' role
     QHash<QString,int>   contactsRole_;
 
