@@ -18,6 +18,7 @@
 #include "msnsockethttp.h"
 
 #include <config-kmess.h>
+#include "../kmessapplication.h"
 #include "../kmessdebug.h"
 
 #include <QNetworkReply>
@@ -157,9 +158,12 @@ void MsnSocketHttp::connectToServer( const QString& server, const quint16 port )
     desiredAddress = server;
   }
 
-#if KMESS_ENABLE_LOCAL_MODE == 1
-  // NOTE Local mode: see src/kmessdebug.h
-  desiredAddress = "127.0.0.1:8008";
+#ifdef KMESSTEST
+  // Redirect to a local socket if started with --usetestserver
+  if( static_cast<KMessApplication*>( kapp )->getUseTestServer() )
+  {
+    desiredAddress = static_cast<KMessApplication*>( kapp )->getTestServer() + ":8008";
+  }
 #endif
 
 #ifdef KMESSDEBUG_CONNECTION_SOCKET_HTTP
@@ -627,7 +631,8 @@ void MsnSocketHttp::slotReplyReceived( QNetworkReply *reply )
 #endif
 
     // We're supposed to clean up
-    delete reply;
+    reply->abort();
+    reply->deleteLater();
 
     return;
   }
@@ -712,7 +717,8 @@ void MsnSocketHttp::slotReplyReceived( QNetworkReply *reply )
     }
 
     // We're supposed to clean up
-    delete reply;
+    reply->abort();
+    reply->deleteLater();
 
     // Allow the connection to continue working: if the error is fatal, the
     // connection will be disconnected so no more messages will be sent
@@ -845,7 +851,8 @@ void MsnSocketHttp::slotReplyReceived( QNetworkReply *reply )
   canSendRequests_ = true;
 
   // We're supposed to clean up
-  delete reply;
+  reply->abort();
+  reply->deleteLater();
 
   // Keep querying for more
   slotQueryServer();
