@@ -537,6 +537,14 @@ void MsnSocketTcp::slotSocketError( QAbstractSocket::SocketError errorCode )
       type = ERROR_DATA;
       break;
 
+    case QAbstractSocket::ProxyConnectionRefusedError:
+    case QAbstractSocket::ProxyConnectionClosedError:
+    case QAbstractSocket::ProxyConnectionTimeoutError:
+    case QAbstractSocket::ProxyNotFoundError:
+    case QAbstractSocket::ProxyProtocolError:
+      type = ERROR_PROXY;
+      break;
+
     default:
       type = ERROR_UNKNOWN;
       break;
