@@ -547,7 +547,7 @@ const QString MsnSwitchboardConnection::convertMsnColorToHtmlColor( QString& col
   // Fill the color out to six characters
   else if( color.length() < 6 )
   {
-    color.rightJustified( 6, '0' );
+    color = color.rightJustified( 6, '0' );
   }
 
   // Get the color components
@@ -1048,7 +1048,7 @@ void MsnSwitchboardConnection::parseChatMessage( const QString &contactHandle, c
   QString         family( message.getSubValue( "X-MMS-IM-Format", "FN" ) );
   const QString& effects( message.getSubValue( "X-MMS-IM-Format", "EF" ) );
   QString          color( message.getSubValue( "X-MMS-IM-Format", "CO" ) );
-
+  
   family = QUrl::fromPercentEncoding( family.toUtf8() );
   color  = convertMsnColorToHtmlColor( color );
 
