@@ -598,6 +598,7 @@ void AddressBookService::parseAddressBook( const QDomElement &body )
     // easy the life of the users...for the moment..:P
     if( handle.isEmpty() || handle == "messenger@microsoft.com" )
     {
+      kWarning() << "Skipped 'messenger@microsoft.com' contact!";
       continue;
     }
 
@@ -723,6 +724,11 @@ void AddressBookService::parseMembershipLists( const QDomElement &body )
             continue;
           }
         }
+        // HACK: See parseAddressBook() for details
+        else if( handle == "messenger@microsoft.com" )
+        {
+          continue;
+        }
 
         // Insert the current contact in the hash with their respective role
         // If the contact is already listed, the new value is OR'ed (set bit flag) with the old roleId
