@@ -449,20 +449,24 @@ void HttpSoapConnection::slotRequestFinished( QNetworkReply *reply )
   // A response has arrived, stop the timeout detection timer
   responseTimer_.stop();
 
-  QByteArray replyContents( reply->readAll() );
-  int     statusCode = reply->attribute( QNetworkRequest::HttpStatusCodeAttribute   ).toInt();
-  QString error(       reply->attribute( QNetworkRequest::HttpReasonPhraseAttribute ).toString() );
+  const QByteArray& replyContents( reply->readAll() );
+  const int           statusCode = reply->attribute( QNetworkRequest::HttpStatusCodeAttribute   ).toInt();
+  const QString&            error( reply->attribute( QNetworkRequest::HttpReasonPhraseAttribute ).toString() );
 
 #ifdef KMESSDEBUG_HTTPSOAPCONNECTION_GENERAL
   bool requestSuccess = false;
-  QUrl replyUrl( reply->url() );
+  const QUrl &replyUrl( reply->url() );
   kDebug() << "Received response: code" << statusCode
            << reply->attribute( QNetworkRequest::HttpReasonPhraseAttribute )
            << " from" << replyUrl;
 #endif
 #ifdef KMESSDEBUG_HTTPSOAPCONNECTION_HTTPDUMP
   kDebug() << "Reply contents:";
-  kDebug() << replyContents;
+
+  // Create the document with the content of SOAP reply to indent it
+  QDomDocument document;
+  document.setContent( replyContents );
+  kDebug() << document.toString();
 #endif
 
   // Parse the body of the HTTP response (copying the other attributes from the request)
