@@ -305,8 +305,8 @@ void PassportLoginService::parseSoapFault( SoapMessage *message )
     login();
 
     // Resend the failed message
-    SoapMessage *message = getCurrentRequest( true /* copy */ );
-    sendSecureRequest( message, inProgressRequests_.value( getCurrentRequest() ) );
+    SoapMessage *messageCopy = getCurrentRequest( true /* copy */ );
+    sendSecureRequest( messageCopy, inProgressRequests_.value( getCurrentRequest() ) );
   }
   else
   {
