@@ -52,6 +52,12 @@ SystemTrayWidget::SystemTrayWidget( QWidget *parent )
   connect( currentAccount_, SIGNAL( changedFriendlyName() ),
            this,            SLOT  (       statusChanged() ) );
 
+  // Connect email related signals
+  connect( currentAccount_, SIGNAL( changedNoEmails() ),
+           this,            SLOT  (       statusChanged() ) );
+  connect( currentAccount_, SIGNAL( changedEmailDisplaySettings() ),
+           this,            SLOT  (       statusChanged() ) );
+
   // Force changing the icon
   statusChanged();
 }
@@ -245,15 +251,21 @@ void SystemTrayWidget::statusChanged()
   {
 #if !defined(Q_WS_WIN)
     newTooltip += i18nc( "Tray icon tooltip, HTML version",
-                         "<br><b>%1</b> (%2)",
+                         "<br><b>%1</b> (%2)%3",
                          currentAccount_->getFriendlyName( STRING_CLEANED_ESCAPED ),
-                         MsnStatus::getName( status ) );
+                         MsnStatus::getName( status ),
+                         currentAccount_->getShowEmail()?
+                           i18nc("Tray icon email count, HTML version", "<br />%1 emails", currentAccount_->getNoEmails()):""
+                         );
 #else
     // Qt on Windows does not support html in the system tray widget.
     newTooltip += i18nc( "Tray icon tooltip, text version",
-                         " - %1 (%2)",
+                         " - %1 (%2)%3",
                          currentAccount_->getFriendlyName( STRING_CLEANED ),
-                         MsnStatus::getName( status ) );
+                         MsnStatus::getName( status ),
+                         currentAccount_->getShowEmail()?
+                           i18nc("Tray icon email count, text version", " - %1 emails", currentAccount_->getNoEmails()):""
+                         );
 #endif
   }
 
